@@ -14,7 +14,6 @@ Long description: This is a simple package to print colored messages using ASCI
 Short description: A module to markup terminal text
 """
 
-
 class colors:
     highlight_dicts = {
         'gray': '\x1b[7m',
@@ -41,18 +40,20 @@ class colors:
         'bold': '\033[1m',
         'underline': '\033[4m',
         'italic': '\x1B[3m',
-        'striked': ''
+        'striked': '',
+        'framed': '\033[52m'
     }
 
 
 clr = ['\033[91m', '\033[38;2;255;69;0m', '\033[93m', '\033[92m', '\033[94m']
 end = '\033[0m'
 
-def prainbow(text: str):
+
+def prainbow(text: str) -> str:
     return ''.join([secrets.choice(clr) + i for i in text]) + end
 
 
-def hex_to_rgb(hexcode):
+def hex_to_rgb(hexcode: str) -> list:
     hexcode = hexcode.lstrip('#')
     hlen = len(hexcode)
     return list(int(hexcode[i:i + hlen // 3], 16) for i in range(0, hlen, hlen // 3))
@@ -62,14 +63,24 @@ def rgb_to_ansii(rgb: list, text: str) -> str:
     return f"\033[38;2;{rgb[0]};{rgb[1]};{rgb[2]}m{text}"
 
 
-def pcolor(text: str,
-           color: typing.Union[list, str],
-           highlight: typing.Union[list, str] = None,
-           markup: list = None,
-           ) -> str:
+def pcolor(
+        text: str,
+        color: typing.Union[list, str],
+        highlight: typing.Union[list, str] = None,
+        markup: list = None,
+        ) -> str:
+
     try:
-        highlightMaybe = ''
-        expression = ''
+
+        color = color.lower() if isinstance(color, str) else color
+        highlight = highlight.lower() if isinstance(highlight, str) else highlight
+        try:
+            markup = [v.lower() for v in markup]
+        except TypeError:
+            pass
+
+        highlightMaybe, expression = '', ''
+
         if type(highlight) == str:
             if highlight in colors.highlight_dicts:
                 highlightMaybe = colors.highlight_dicts[highlight]
@@ -86,8 +97,11 @@ def pcolor(text: str,
             expression = rgb_to_ansii(color, text) + end
 
         if type(color) == str:
-            torgb = hex_to_rgb(color)
-            expression = rgb_to_ansii(torgb, text) + end
+            if color in colors.color_dict:
+                expression = colors.color_dict[color] + text + end
+            else:
+                torgb = hex_to_rgb(color)
+                expression = rgb_to_ansii(torgb, text) + end
 
         if markup is None:
             if highlight is None:
@@ -114,9 +128,8 @@ def pcolor(text: str,
         else:
             raise KeyError
 
-    except (KeyError, ValueError, IndexError):
+    except (KeyError, ValueError, IndexError, AttributeError):
         raise KeyError('You\'re proving a invalid argument, please look at the acceptable options at '
                        'https://www.github.com/ammar-sys/terminalcolorpy')
 
-
 pc, pr = pcolor, prainbow
